@@ -20,7 +20,6 @@ QuestionSet::QuestionSet(Rcpp::S4 &cat_df) {
 		difficulty.push_back(Rcpp::as<std::vector<double> >(item));
 	}
 
-	
 	reset_applicables();
 	reset_all_extreme();
 }
@@ -29,8 +28,8 @@ void QuestionSet::reset_answers(Rcpp::DataFrame& responses, size_t row)
 {
 	for(size_t i = 0; i < answers.size(); ++i)
 	{
-		Rcpp::IntegerVector col = responses[i]; 
-		answers[i] = col[row];
+		Rcpp::IntegerVector col = responses.at(i); 
+		answers.at(i) = col.at(row);
 	}
 	
 	reset_applicables();
@@ -46,13 +45,13 @@ void QuestionSet::reset_answers(std::vector<int> const& source)
 
 void QuestionSet::reset_answer(size_t question, int answer)
 {
-	if(answer == answers[question])
+	if(answer == answers.at(question))
 	{
 		return; // nothing to be done
 	}
 
-	int old_answer = answers[question];
-	answers[question] = answer;
+	int old_answer = answers.at(question);
+	answers.at(question) = answer;
 
 	
 	if(old_answer == NA_INTEGER)
@@ -152,38 +151,57 @@ void QuestionSet::reset_applicables()
 
 void QuestionSet::reset_all_extreme()
 {
-	// Added all this is to check if its appropriate to use MLE
-	bool minAnswer_posDiscrim = false;
-	bool maxAnswer_posDiscrim = false;
-	bool minAnswer_negDiscrim = false;
-	bool maxAnswer_negDiscrim = false;
-	bool ans_not_extreme = false;
-	
-	int max_response = ((model == "ltm") | (model == "tpm")) ? 1.0 : difficulty[1].size() + 1.0;
-	int min_response = ((model == "ltm") | (model == "tpm")) ? 0.0 : 1.0;
-
-	for (auto i : applicable_rows) {
-	  	if (discrimination.at(i) < 0.0 and answers.at(i) == min_response) minAnswer_negDiscrim = true;
-	  	else if (discrimination.at(i) < 0.0 and answers.at(i) == max_response) maxAnswer_negDiscrim = true;
-	  	else if (discrimination.at(i) > 0.0 and answers.at(i) == min_response) minAnswer_posDiscrim = true;
-	  	else if (discrimination.at(i) > 0.0 and answers.at(i) == max_response) maxAnswer_posDiscrim = true;
-	  	else
-	  	{
-	  		ans_not_extreme = true;
-	  		break;
-	  	}
-	}
-
-	all_extreme = false;
-
-	if(!ans_not_extreme)
-	{
-		if (minAnswer_posDiscrim and maxAnswer_negDiscrim and (!minAnswer_negDiscrim)  and (!maxAnswer_posDiscrim))
-		{
-	  		all_extreme = true;
-		} else if ((!minAnswer_posDiscrim)  and (!maxAnswer_negDiscrim) and minAnswer_negDiscrim and maxAnswer_posDiscrim)
-		{
-	  		all_extreme = true;
-		}
-	}
+    
+    std::vector<bool> minAnswer_posDiscrim;
+    std::vector<bool> maxAnswer_posDiscrim;
+    std::vector<bool> minAnswer_negDiscrim;
+    std::vector<bool> maxAnswer_negDiscrim;
+    
+    int min_response = ((model == "ltm") | (model == "tpm")) ? 0.0 : 1.0;
+    
+    
+    for (auto i : applicable_rows) {
+        int max_response = ((model == "ltm") | (model == "tpm")) ? 1.0 : difficulty.at(i).size() + 1.0;
+        
+        if (discrimination.at(i) < 0.0 and answers.at(i) == min_response){
+            minAnswer_negDiscrim.push_back(true); 
+        } else {
+            minAnswer_negDiscrim.push_back(false); 
+        }
+        
+        if (discrimination.at(i) < 0.0 and answers.at(i) == max_response) {
+            maxAnswer_negDiscrim.push_back(true);
+        } else {
+            maxAnswer_negDiscrim.push_back(false);
+        }
+        
+        
+        if (discrimination.at(i) > 0.0 and answers.at(i) == min_response) {
+            minAnswer_posDiscrim.push_back(true);
+        } else {
+            minAnswer_posDiscrim.push_back(false);
+        }
+        
+        
+        if (discrimination.at(i) > 0.0 and answers.at(i) == max_response) {
+            maxAnswer_posDiscrim.push_back(true);
+        } else {
+            maxAnswer_posDiscrim.push_back(false);
+        }
+    }
+    
+    size_t sum_1 = 0;
+    for (auto i : minAnswer_negDiscrim) sum_1 += i;
+    for (auto i : maxAnswer_posDiscrim) sum_1 += i;
+    
+    size_t sum_2 = 0;
+    for (auto i : minAnswer_posDiscrim) sum_2 += i;
+    for (auto i : maxAnswer_negDiscrim) sum_2 += i;
+    
+    if ((sum_1 == applicable_rows.size()) || (sum_2 == applicable_rows.size())){
+        all_extreme = true;
+    } else {
+        all_extreme = false;
+    }
+    
 }
